@@ -31,7 +31,9 @@ def get_mapd_type_from_known(dtype):
     if is_bool_dtype(dtype):
         return 'BOOL'
     elif is_integer_dtype(dtype):
-        if dtype.itemsize <= 2:
+        if dtype.itemsize <= 1:
+            return 'TINYINT'
+        elif dtype.itemsize == 2:
             return 'SMALLINT'
         elif dtype.itemsize == 4:
             return 'INT'
@@ -51,7 +53,7 @@ def get_mapd_type_from_known(dtype):
 def get_mapd_type_from_object(data):
     """For cases where the type system mismatches"""
     try:
-        val = data.dropna()[0]
+        val = data.dropna().iloc[0]
     except IndexError:
         raise IndexError("Not any valid values to infer the type")
     if isinstance(val, six.string_types):
