@@ -2,6 +2,7 @@
 Connect to a MapD database.
 """
 from collections import namedtuple
+import base64
 
 import six
 from sqlalchemy.engine.url import make_url
@@ -10,6 +11,7 @@ from thrift.transport import TSocket, THttpClient, TTransport
 from thrift.transport.TSocket import TTransportException
 from mapd.MapD import Client
 from mapd.ttypes import TMapDException
+from mapd.MapD import TDeviceType
 
 from .cursor import Cursor
 from .exceptions import _translate_exception, OperationalError
@@ -157,6 +159,7 @@ class Connection(object):
         self._protocol = protocol
         self._socket = socket
         self._closed = 0
+        self._tdf = None
         try:
             self._transport.open()
         except TTransportException as e:
@@ -265,6 +268,7 @@ class Connection(object):
 
         tdf = self._client.sql_execute_gdf(
             self._session, operation, device_id=device_id, first_n=first_n)
+        self._tdf = tdf
         return _parse_tdf_gpu(tdf)
 
     def select_ipc(self, operation, parameters=None, first_n=-1):
@@ -304,14 +308,50 @@ class Connection(object):
             self._session, operation, device_type=0, device_id=0,
             first_n=first_n
         )
+        self._tdf = tdf
 
         sm_buf = load_buffer(tdf.sm_handle, tdf.sm_size)
         df_buf = load_buffer(tdf.df_handle, tdf.df_size)
 
         schema = _load_schema(sm_buf)
-        df = _load_data(df_buf, schema)
+        df = _load_data(df_buf, schema, tdf)
         return df
 
+    def deallocate_ipc_gpu(self, df, device_id=0):
+        # type: () -> None
+        """Deallocate a DataFrame using GPU memory.
+
+        Parameters
+        ----------
+        device_id : int
+            GPU which contains TDataFrame
+        """
+
+        tdf = df.get_tdf()
+        result = self._client.deallocate_df(
+                session=self._session,
+                df=tdf,
+                device_type=TDeviceType.GPU,
+                device_id=device_id)
+        return result
+
+    def deallocate_ipc(self, df, device_id=0):
+        # type: () -> None
+        """Deallocate a DataFrame using CPU shared memory.
+
+        Parameters
+        ----------
+        device_id : int
+            GPU which contains TDataFrame
+        """
+        tdf = df.get_tdf()
+        result = self._client.deallocate_df(
+                session=self._session,
+                df=tdf,
+                device_type=TDeviceType.CPU,
+                device_id=device_id)
+        return result
+
     # --------------------------------------------------------------------------
     # Convenience methods
     # --------------------------------------------------------------------------
@@ -521,6 +561,43 @@ class Connection(object):
         self._client.load_table_binary_arrow(self._session, table_name,
                                              payload.to_pybytes())
 
+    def render_vega(self, vega, compression_level=1):
+        """Render vega data on the database backend,
+        returning the image as a PNG.
+
+        Parameters
+        ----------
+
+        vega : dict
+            The vega specification to render.
+        compression_level: int
+            The level of compression for the rendered PNG. Ranges from
+            0 (low compression, faster) to 9 (high compression, slower).
+        """
+        result = self._client.render_vega(
+                self._session,
+                widget_id=None,
+                vega_json=vega,
+                compression_level=compression_level,
+                nonce=None
+                )
+        rendered_vega = RenderedVega(result)
+        return rendered_vega
+
+
+class RenderedVega(object):
+    def __init__(self, render_result):
+        self._render_result = render_result
+        self.image_data = base64.b64encode(render_result.image).decode()
+
+    def _repr_mimebundle_(self, include=None, exclude=None):
+        return {
+            'image/png': self.image_data,
+            'text/html':
+                '<img src="data:image/png;base64,{}" alt="MapD Vega">'
+                .format(self.image_data)
+            }
+
 
 def _is_pandas(data):
     try:
