@@ -117,7 +117,7 @@ class Cursor(object):
             result = self.connection._client.sql_execute(
                 self.connection._session, operation,
                 column_format=self.columnar,
-                nonce=None, first_n=-1)
+                nonce=None, first_n=-1, at_most_n=-1)
         except T.TMapDException as e:
             six.raise_from(_translate_exception(e), e)
         self._description = _extract_description(result.row_set.row_desc)
