@@ -39,9 +39,10 @@ Time = datetime.time
 Timestamp = datetime.datetime
 
 BINARY = DataType([])
-STRING = DataType([T.STR])
+STRING = DataType([T.STR, T.POINT, T.LINESTRING, T.POLYGON,
+                   T.MULTIPOLYGON, T.GEOMETRY, T.GEOGRAPHY])
 NUMBER = DataType([T.SMALLINT, T.INT, T.BIGINT, T.FLOAT, T.DECIMAL, T.DOUBLE,
-                   T.BOOL])
+                   T.BOOL, T.TINYINT])
 DATETIME = DataType([T.DATE, T.TIME, T.TIMESTAMP])
 ROWID = DataType([])
 
